@@ -16,6 +16,9 @@ object Constants {
     /** The "Coastal" terrain _filter_ */
     const val coastal = "Coastal"
 
+    /** Used as filter and the name of the pseudo-TerrainFeature defining river Stats */
+    const val river = "River"
+
     const val mountain = "Mountain"
     const val hill = "Hill"
     const val plains = "Plains"
@@ -43,6 +46,7 @@ object Constants {
     const val peaceTreaty = "Peace Treaty"
     const val researchAgreement = "Research Agreement"
     const val openBorders = "Open Borders"
+    const val defensivePact = "Defensive Pact"
     /** Used as origin in StatMap or ResourceSupplyList, or the toggle button in DiplomacyOverviewTab */
     const val cityStates = "City-States"
     /** Used as origin in ResourceSupplyList */
