@@ -38,6 +38,7 @@ import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.ui.screens.mainmenuscreen.MainMenuScreen
 import com.unciv.ui.screens.savescreens.LoadGameScreen
 import com.unciv.ui.screens.worldscreen.PlayerReadyScreen
+import com.unciv.ui.screens.worldscreen.UndoHandler.Companion.clearUndoCheckpoints
 import com.unciv.ui.screens.worldscreen.WorldMapHolder
 import com.unciv.ui.screens.worldscreen.WorldScreen
 import com.unciv.ui.screens.worldscreen.unit.UnitTable
@@ -111,6 +112,11 @@ object GUI {
         return UncivGame.Current.worldScreen!!.selectedCiv
     }
 
+    /** Disable Undo (as in: forget the way back, but allow future undo checkpoints) */
+    fun clearUndoCheckpoints() {
+        UncivGame.Current.worldScreen?.clearUndoCheckpoints()
+    }
+
     private var keyboardAvailableCache: Boolean? = null
     /** Tests availability of a physical keyboard */
     val keyboardAvailable: Boolean
@@ -538,7 +544,7 @@ open class UncivGame(val isConsoleMode: Boolean = false) : Game(), PlatformSpeci
 
     companion object {
         //region AUTOMATICALLY GENERATED VERSION DATA - DO NOT CHANGE THIS REGION, INCLUDING THIS COMMENT
-        val VERSION = Version("4.8.15", 925)
+        val VERSION = Version("4.8.19", 929)
         //endregion
 
         lateinit var Current: UncivGame
