@@ -74,7 +74,7 @@ object UniqueTriggerActivation {
 
                 civInfo.addNotification(
                     notificationText,
-                    MapUnitAction(placedUnit.getTile().position),
+                    MapUnitAction(placedUnit),
                     NotificationCategory.Units,
                     placedUnit.name
                 )
@@ -142,7 +142,7 @@ object UniqueTriggerActivation {
                     civInfo.addNotification(
                         notificationText,
                         sequence {
-                            yield(MapUnitAction(placedUnit.getTile().position))
+                            yield(MapUnitAction(placedUnit))
                             yieldAll(LocationAction(tile?.position))
                         },
                         NotificationCategory.Units,
@@ -342,11 +342,11 @@ object UniqueTriggerActivation {
             }
 
             UniqueType.OneTimeProvideResources -> {
-                val amount = unique.params[0].toInt()
                 val resourceName = unique.params[1]
                 val resource = ruleSet.tileResources[resourceName] ?: return false
                 if (!resource.isStockpiled()) return false
 
+                val amount = unique.params[0].toInt()
                 civInfo.resourceStockpiles.add(resourceName, amount)
 
                 val notificationText = getNotificationText(notification, triggerNotificationText,
@@ -358,11 +358,11 @@ object UniqueTriggerActivation {
             }
 
             UniqueType.OneTimeConsumeResources -> {
-                val amount = unique.params[0].toInt()
                 val resourceName = unique.params[1]
                 val resource = ruleSet.tileResources[resourceName] ?: return false
                 if (!resource.isStockpiled()) return false
 
+                val amount = unique.params[0].toInt()
                 civInfo.resourceStockpiles.add(resourceName, -amount)
 
                 val notificationText = getNotificationText(notification, triggerNotificationText,
